from django.shortcuts import render
from django.conf import settings
from django.utils.safestring import mark_safe

def discovery(request):
    return render(request, 'shibboleth_eds/discovery.html', {
        'non_js_url': getattr(settings, 'SHIBBOLETH_EDS_NON_JS_URL', 'http://federation.org/DS/DS?entityID=https%3A%2F%2FyourentityId.edu.edu%2Fshibboleth&return=https%3A%2F%2Fyourreturn.edu%2FShibboleth.sso%2FDS%3FSAMLDS%3D1%26target%3Dhttps%3A%2F%2Fyourreturn.edu%2F'),
    })

def config(request):
    return render(request, 'shibboleth_eds/idpselect_config.js', {
        'dataSource': getattr(settings, 'SHIBBOLETH_EDS_DATA_SOURCE', '/Shibboleth.sso/DiscoFeed'),
        'defaultReturn': mark_safe(getattr(settings, 'SHIBBOLETH_EDS_DEFAULT_RETURN', 'null')),
        'defaultLogo': getattr(settings, 'SHIBBOLETH_EDS_DEFAULT_LOGO', '/media/assets/shibboleth_eds/blank.gif'),
        'helpURL': getattr(settings, 'SHIBBOLETH_EDS_HELP_URL', 'https://wiki.shibboleth.net/confluence/display/DEV/EDSDetails'),
        'preferredIdP': mark_safe(getattr(settings, 'SHIBBOLETH_EDS_PREFERRED_IDPS', 'null')),
        'hiddenIdPs': mark_safe(getattr(settings, 'SHIBBOLETH_EDS_HIDDEN_IDPS', 'null')),
        'showListFirst': getattr(settings, 'SHIBBOLETH_EDS_SHOW_LIST_FIRST', 'false'),
        'autoFollowCookie': mark_safe(getattr(settings, 'SHIBBOLETH_EDS_FOLLOW_COOKIE', 'null')),
    }, content_type='application/javascript')



#!/usr/bin/python
# -*- coding: utf8 -*-

import os
from setuptools import find_packages, setup

with open(os.path.join(os.path.dirname(__file__), 'README.md')) as readme:
    README = readme.read()

# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

setup(
    name='django-shibboleth-eds',
    version='0.7',
    packages=find_packages(),
    include_package_data=True,
    license='Apache 2.0',
    description='Django app to embed Shibboleth Embedded Discovery Service into your Django project.',
    long_description=README,
    url='https://github.com/hu-berlin-cms/django-shibboleth-eds',
    author='Enno Gröper',
    author_email='enno.groeper@cms.hu-berlin.de',
    classifiers=[
        'Environment :: Web Environment',
        'Framework :: Django',
        'Framework :: Django :: 1.11',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Apache Software License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        # Replace these appropriately if you are stuck on Python 2.
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    ],
)
